Computes student statistics in Polish districts.Calculates in Python basic statistics like min/average/max number of:
●students per teacher broken down by the type of school,
●students per school broken down by their year of birth,in each district (polish ‘gmina’) and in total for cities and rural districts.